pub enum IncludeProjectDirectoryResolution {
Resolved(PathBuf),
Deferred,
}Expand description
The successful result of resolving an explicit include project directory.
Variants
Resolved(PathBuf)
The caller authorized this effective directory.
Deferred
The caller intentionally deferred this declaration without producing an error.