IncludeLoader

Trait IncludeLoader 

pub trait IncludeLoader {
    // Required method
    fn load_include(
        &self,
        request: &IncludeRequest,
    ) -> Result<IncludedProjectInput, IncludeLoadError>;
}
The only authorization and I/O boundary used by recursive include traversal.

Required Methods

fn load_include( &self, request: &IncludeRequest, ) -> Result<IncludedProjectInput, IncludeLoadError>

Authorizes and loads one requested included project.

Implementations may use files, editor buffers, archives, URIs, or another caller policy. ComposeLens itself performs none of those operations.

Errors

Returns an IncludeLoadError when caller policy denies the request or the selected external source cannot supply a project input.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors