pub struct MergedEntry { /* private fields */ }Expand description
One mapping entry in a merged semantic view.
Implementations
Sourceimpl MergedEntry
impl MergedEntry
Sourcepub fn key_sources(&self) -> &[SourceSpan]
pub fn key_sources(&self) -> &[SourceSpan]
Returns every authored key location that participated in this entry.
Sourcepub const fn syntax(&self) -> EntrySyntax
pub const fn syntax(&self) -> EntrySyntax
Returns the most recent authored syntax form for this entry.
Sourcepub const fn value(&self) -> &MergedValue
pub const fn value(&self) -> &MergedValue
Returns the merged entry value.