#[non_exhaustive]pub enum AnnotationsForm {
Map(Vec<KeyValueEntry>),
List(Vec<Located<ComposeScalar>>),
}Expand description
The exact authored mapping or list form of service annotations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Map(Vec<KeyValueEntry>)
Ordered mapping syntax with scalar kinds and spelling retained.
List(Vec<Located<ComposeScalar>>)
Ordered raw scalar list items, including invalid scalar kinds retained for diagnostics.