pub enum ComposeScalar {
Null,
Boolean(bool),
Number(String),
String(String),
}Expand description
A YAML scalar retained without applying Compose interpolation or coercion.
Variants
Null
An explicit YAML null.
Boolean(bool)
A YAML boolean.
Number(String)
A numeric scalar with its authored semantic spelling retained.
String(String)
A string scalar, which may still contain interpolation expressions.