#[non_exhaustive]pub enum DeployRollbackOrder {
StopFirst,
StartFirst,
Other(String),
}Expand description
Rollback order with unsupported values retained.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
StopFirst
Stop the old task before starting the new task.
StartFirst
Start the new task before stopping the old task.
Other(String)
A retained provider-specific order.