#[non_exhaustive]pub enum ExposeItemKind {
Documented {
port: ExposePort,
protocol: Option<ExposeProtocol>,
},
Sctp {
port: ExposePort,
},
UnknownProtocol {
port: ExposePort,
protocol: String,
},
Expression,
Malformed,
}Expand description
The conservative semantic family of one service expose item.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Documented
A documented decimal port or range with an omitted, tcp, or udp suffix.
Fields

port: ExposePortExact decimal port or range components.

protocol: Option<ExposeProtocol>Exact documented protocol when explicitly present.
Sctp
A well-shaped decimal port or range using the schema-recognized sctp suffix.
Fields

port: ExposePortExact decimal port or range components.
UnknownProtocol
A well-shaped decimal port or range using another raw protocol token.
Fields

port: ExposePortExact decimal port or range components.
Expression
A string whose effective spelling depends on Compose interpolation.
Malformed
An empty or otherwise malformed scalar retained for diagnostics.