#[non_exhaustive]pub enum GpuOptions {
Mapping(Vec<KeyValueEntry>),
List(Vec<Located<String>>),
}Expand description
GPU selector options in their authored mapping or list form.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Mapping(Vec<KeyValueEntry>)
Ordered mapping entries with scalar values.
List(Vec<Located<String>>)
Ordered raw string option entries.
Implementations
Sourceimpl GpuOptions
impl GpuOptions
Sourcepub fn as_mapping(&self) -> Option<&[KeyValueEntry]>
pub fn as_mapping(&self) -> Option<&[KeyValueEntry]>
Returns mapping entries when the selector used mapping syntax.