#[non_exhaustive]pub enum HostnameKind {
Resolved,
Expression,
Invalid,
}Expand description
The semantic family of a service-level Compose hostname.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Resolved
A resolved ASCII hostname satisfying the conservative RFC-1123 grammar.
Expression
A scalar containing a dollar marker and therefore deferred to interpolation.
Invalid
A resolved literal that does not satisfy the conservative hostname grammar.