#[non_exhaustive]pub enum PidsLimitKind {
Unlimited,
Finite {
decimal: String,
},
Zero,
Expression,
Other,
}Expand description
The semantic family of a service-level Compose PID limit.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unlimited
No PID limit, authored as -1.
Finite
A positive integral decimal retained without fixed-width parsing or normalization.
Zero
An all-zero integral spelling retained as an ambiguous and unportable native state.
Expression
A scalar that still contains a Compose interpolation marker.
Other
A fractional, signed, exponent, or otherwise unsupported scalar retained for diagnostics.