#[non_exhaustive]pub enum RestartPolicyKind {
No,
Always,
OnFailure {
maximum_retries: Option<String>,
},
UnlessStopped,
Expression,
Other,
}Expand description
The recognized family of a service-level Compose restart policy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
No
Never restart the container automatically.
Always
Always restart the container until it is removed.
OnFailure
Restart after an error, optionally with the authored maximum-retry spelling.
Fields
UnlessStopped
Restart except after an explicit stop or removal.
Expression
A policy that still contains a Compose interpolation expression.
Other
An invalid or provider-specific value retained for diagnostics.