#[non_exhaustive]pub enum SysctlsForm {
Map(Vec<KeyValueEntry>),
List(Vec<Located<String>>),
}Expand description
The exact authored mapping or list form of service sysctls.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Map(Vec<KeyValueEntry>)
Ordered mapping syntax with exact scalar value kinds and spelling retained.
List(Vec<Located<String>>)
Ordered list syntax with exact string items retained.