#[non_exhaustive]pub enum TmpfsForm {
Scalar(TmpfsItem),
List(Vec<TmpfsItem>),
}Expand description
The exact authored scalar or sequence form of service-level tmpfs.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Scalar(TmpfsItem)
One scalar temporary-filesystem declaration.
List(Vec<TmpfsItem>)
An explicitly authored sequence, including an explicit empty sequence.