#[non_exhaustive]pub enum TmpfsItemKind {
Expression,
Documented,
ProviderDependent,
}Expand description
The conservative semantic family of one service-level tmpfs item.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Expression
A dollar-bearing item whose effective spelling depends on Compose interpolation.
Documented
A non-empty path with only non-empty mode, uid, or gid option assignments.
ProviderDependent
An empty or malformed item, or one using provider- or target-specific options.