pub struct Annotations { /* private fields */ }Expand description
An explicitly authored service-level Compose annotations value.
Implementations
Sourceimpl Annotations
impl Annotations
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the exact span of the complete authored collection.
Sourcepub const fn form(&self) -> &AnnotationsForm
pub const fn form(&self) -> &AnnotationsForm
Returns the authored mapping or list form without semantic normalization.