pub struct BlkioDeviceRate { /* private fields */ }Expand description
One ordered block-I/O device rate item.
Implementations
Sourceimpl BlkioDeviceRate
impl BlkioDeviceRate
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the complete item span.
Sourcepub const fn form(&self) -> BlkioDeviceRateForm
pub const fn form(&self) -> BlkioDeviceRateForm
Returns whether this entry was a mapping or retained unmodeled sequence item.
Sourcepub const fn path(&self) -> Option<&Located<String>>
pub const fn path(&self) -> Option<&Located<String>>
Returns the raw device path when its YAML-string form was valid.
Sourcepub const fn rate(&self) -> Option<&Located<BlkioScalar>>
pub const fn rate(&self) -> Option<&Located<BlkioScalar>>
Returns the raw integer-or-string rate when its scalar form was valid.
Sourcepub fn extension_fields(&self) -> &[FieldReference]
pub fn extension_fields(&self) -> &[FieldReference]
Returns retained extensions on this entry.
Sourcepub fn unknown_fields(&self) -> &[FieldReference]
pub fn unknown_fields(&self) -> &[FieldReference]
Returns retained unknown or malformed members on this entry.