pub struct BlkioWeightDevice { /* private fields */ }Expand description
One ordered block-I/O device weight item.
Implementations
Sourceimpl BlkioWeightDevice
impl BlkioWeightDevice
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the complete item span.
Sourcepub const fn form(&self) -> BlkioWeightDeviceForm
pub const fn form(&self) -> BlkioWeightDeviceForm
Returns whether this entry was a mapping or retained unmodeled sequence item.
Sourcepub const fn path(&self) -> Option<&Located<String>>
pub const fn path(&self) -> Option<&Located<String>>
Returns the raw device path when its YAML-string form was valid.
Sourcepub const fn weight(&self) -> Option<&Located<BlkioScalar>>
pub const fn weight(&self) -> Option<&Located<BlkioScalar>>
Returns the raw integer-or-string weight when its scalar form was valid.
Sourcepub fn extension_fields(&self) -> &[FieldReference]
pub fn extension_fields(&self) -> &[FieldReference]
Returns retained extensions on this entry.
Sourcepub fn unknown_fields(&self) -> &[FieldReference]
pub fn unknown_fields(&self) -> &[FieldReference]
Returns retained unknown or malformed members on this entry.