pub struct ExposeItem { /* private fields */ }Expand description
One exact source-aware service expose sequence item.
Implementations
Sourceimpl ExposeItem
impl ExposeItem
Sourcepub fn value(&self) -> &str
pub fn value(&self) -> &str
Returns the exact scalar value without normalizing its port, range, or protocol.
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the exact source span of this scalar item.
Sourcepub const fn scalar_kind(&self) -> ExposeScalarKind
pub const fn scalar_kind(&self) -> ExposeScalarKind
Returns whether the authored YAML scalar was a string or number.
Sourcepub const fn kind(&self) -> &ExposeItemKind
pub const fn kind(&self) -> &ExposeItemKind
Returns the conservative raw-preserving item classification.