pub struct ExternalNameMapping { /* private fields */ }Expand description
The deprecated Compose external: { name: ... } mapping.
Implementations
Sourceimpl ExternalNameMapping
impl ExternalNameMapping
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the complete deprecated mapping span.
Sourcepub const fn name(&self) -> Option<&Located<String>>
pub const fn name(&self) -> Option<&Located<String>>
Returns the deprecated external resource name when it is a YAML string.
Sourcepub fn extension_fields(&self) -> &[FieldReference]
pub fn extension_fields(&self) -> &[FieldReference]
Returns retained x- fields in the deprecated mapping.
Sourcepub fn unknown_fields(&self) -> &[FieldReference]
pub fn unknown_fields(&self) -> &[FieldReference]
Returns unrecognized or malformed fields in the deprecated mapping.