pub struct Healthcheck { /* private fields */ }Expand description
A service health-check definition.
Implementations
Sourceimpl Healthcheck
impl Healthcheck
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the complete health-check mapping span.
Sourcepub const fn test(&self) -> Option<&HealthcheckTest>
pub const fn test(&self) -> Option<&HealthcheckTest>
Returns the health command with its scalar/list form retained.
Sourcepub const fn interval(&self) -> Option<&Located<HealthcheckDuration>>
pub const fn interval(&self) -> Option<&Located<HealthcheckDuration>>
Returns the explicitly authored interval.
Sourcepub const fn timeout(&self) -> Option<&Located<HealthcheckDuration>>
pub const fn timeout(&self) -> Option<&Located<HealthcheckDuration>>
Returns the explicitly authored timeout.
Sourcepub const fn retries(&self) -> Option<&Located<HealthcheckRetries>>
pub const fn retries(&self) -> Option<&Located<HealthcheckRetries>>
Returns the explicitly authored retry count.
Sourcepub const fn start_period(&self) -> Option<&Located<HealthcheckDuration>>
pub const fn start_period(&self) -> Option<&Located<HealthcheckDuration>>
Returns the explicitly authored start period.
Sourcepub const fn start_interval(&self) -> Option<&Located<HealthcheckDuration>>
pub const fn start_interval(&self) -> Option<&Located<HealthcheckDuration>>
Returns the explicitly authored start interval.
Sourcepub const fn disable(&self) -> Option<&Located<BooleanValue>>
pub const fn disable(&self) -> Option<&Located<BooleanValue>>
Returns whether the image health check is explicitly disabled.
Sourcepub fn is_disabled(&self) -> bool
pub fn is_disabled(&self) -> bool
Reports whether the authored health check is explicitly disabled.
Sourcepub fn extension_fields(&self) -> &[FieldReference]
pub fn extension_fields(&self) -> &[FieldReference]
Returns retained x- fields.
Sourcepub fn unknown_fields(&self) -> &[FieldReference]
pub fn unknown_fields(&self) -> &[FieldReference]
Returns unrecognized health-check fields.