pub struct ImageMountOptions { /* private fields */ }Expand description
Image-specific options in a long-syntax service-volume mount.
Implementations
Sourceimpl ImageMountOptions
impl ImageMountOptions
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the complete image mapping span.
Sourcepub const fn subpath(&self) -> Option<&Located<String>>
pub const fn subpath(&self) -> Option<&Located<String>>
Returns the authored image subpath without resolving an image or filesystem.
Sourcepub fn extension_fields(&self) -> &[FieldReference]
pub fn extension_fields(&self) -> &[FieldReference]
Returns retained x- image fields.
Sourcepub fn unknown_fields(&self) -> &[FieldReference]
pub fn unknown_fields(&self) -> &[FieldReference]
Returns unrecognized or malformed image fields retained from source.