pub struct Logging { /* private fields */ }Expand description
An explicitly authored service-level Compose logging mapping.
Implementations
Sourceimpl Logging
impl Logging
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the exact span of the complete authored logging mapping.
Sourcepub const fn driver(&self) -> Option<&Located<String>>
pub const fn driver(&self) -> Option<&Located<String>>
Returns the exact uninterpreted string driver when validly authored.
Sourcepub const fn options(&self) -> Option<&LoggingOptions>
pub const fn options(&self) -> Option<&LoggingOptions>
Returns the ordered options mapping, including an explicitly empty one.
Sourcepub fn extension_fields(&self) -> &[FieldReference]
pub fn extension_fields(&self) -> &[FieldReference]
Returns retained x-* fields from the logging mapping.
Sourcepub fn unknown_fields(&self) -> &[FieldReference]
pub fn unknown_fields(&self) -> &[FieldReference]
Returns unrecognized fields from the logging mapping.