pub struct LongDevice { /* private fields */ }Expand description
One mapping-form service device declaration.
Implementations
Sourceimpl LongDevice
impl LongDevice
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the complete mapping span.
Sourcepub const fn source(&self) -> Option<&Located<String>>
pub const fn source(&self) -> Option<&Located<String>>
Returns the required source when it was valid and present.
Sourcepub const fn target(&self) -> Option<&Located<String>>
pub const fn target(&self) -> Option<&Located<String>>
Returns the optional target without host/container path interpretation.
Sourcepub const fn permissions(&self) -> Option<&Located<String>>
pub const fn permissions(&self) -> Option<&Located<String>>
Returns the optional raw permissions string without validating its letters or meaning.
Sourcepub fn extension_fields(&self) -> &[FieldReference]
pub fn extension_fields(&self) -> &[FieldReference]
Returns retained x- options in authored order.
Sourcepub fn unknown_fields(&self) -> &[FieldReference]
pub fn unknown_fields(&self) -> &[FieldReference]
Returns unrecognized mapping options in authored order.