pub struct SecurityOptions { /* private fields */ }Expand description
An explicitly authored ordered service security_opt sequence.
Omission is represented by absence of this value. An empty item vector therefore retains an explicitly authored empty sequence.
Implementations
Sourceimpl SecurityOptions
impl SecurityOptions
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the span of the complete authored sequence.
Sourcepub fn items(&self) -> &[SecurityOptionItem]
pub fn items(&self) -> &[SecurityOptionItem]
Returns every valid string item in authored order, including duplicates and empty strings.