pub struct Sysctls { /* private fields */ }Expand description
An explicitly authored service-level Compose sysctls value.
Implementations
Sourceimpl Sysctls
impl Sysctls
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the exact span of the complete authored collection.
Sourcepub const fn form(&self) -> &SysctlsForm
pub const fn form(&self) -> &SysctlsForm
Returns the authored mapping or list form without coercion or normalization.