pub struct TmpfsItem { /* private fields */ }Expand description
One exact service-level tmpfs item.
Implementations
Sourceimpl TmpfsItem
impl TmpfsItem
Sourcepub fn value(&self) -> &str
pub fn value(&self) -> &str
Returns the exact string value without normalizing its path or options.
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the exact source span of this scalar item.
Sourcepub const fn kind(&self) -> TmpfsItemKind
pub const fn kind(&self) -> TmpfsItemKind
Returns the conservative raw-preserving item classification.