#[non_exhaustive]pub enum ProjectBuildExtraHostAddresses {
Scalar(ProjectValue<String>),
List(Vec<ProjectValue<String>>),
}Expand description
Effective build-host addresses for one mapping key.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Scalar(ProjectValue<String>)
One raw string address.
List(Vec<ProjectValue<String>>)
Ordered raw string addresses.
Implementations
Sourceimpl ProjectBuildExtraHostAddresses
impl ProjectBuildExtraHostAddresses
Sourcepub const fn as_scalar(&self) -> Option<&ProjectValue<String>>
pub const fn as_scalar(&self) -> Option<&ProjectValue<String>>
Returns the scalar address when that effective form is present.
Sourcepub fn as_list(&self) -> Option<&[ProjectValue<String>]>
pub fn as_list(&self) -> Option<&[ProjectValue<String>]>
Returns the ordered address list when that effective form is present.