#[non_exhaustive]pub enum ProjectDeployReservationDeviceOptions {
Map {
entries: Vec<ProjectValue<ProjectDeployReservationDeviceOption>>,
unmodeled_entries: Vec<ProjectFieldReference>,
},
List(Vec<ProjectValue<ProjectDeployReservationDeviceOptionItem>>),
}Expand description
Effective schema-shaped resource-reservation device options.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Map
Ordered mapping entries plus malformed fields retained as evidence.
Fields

entries: Vec<ProjectValue<ProjectDeployReservationDeviceOption>>Valid map entries with key and value provenance.

unmodeled_entries: Vec<ProjectFieldReference>Malformed or duplicate map fields.
List(Vec<ProjectValue<ProjectDeployReservationDeviceOptionItem>>)
Ordered list entries, including malformed items.
Implementations
Sourceimpl ProjectDeployReservationDeviceOptions
impl ProjectDeployReservationDeviceOptions
Sourcepub fn as_map(
&self,
) -> Option<&[ProjectValue<ProjectDeployReservationDeviceOption>]>
pub fn as_map( &self, ) -> Option<&[ProjectValue<ProjectDeployReservationDeviceOption>]>
Returns valid mapping entries when the effective form was a mapping.
Sourcepub fn unmodeled_entries(&self) -> Option<&[ProjectFieldReference]>
pub fn unmodeled_entries(&self) -> Option<&[ProjectFieldReference]>
Returns malformed or duplicate mapping fields when the effective form was a mapping.
Sourcepub fn as_list(
&self,
) -> Option<&[ProjectValue<ProjectDeployReservationDeviceOptionItem>]>
pub fn as_list( &self, ) -> Option<&[ProjectValue<ProjectDeployReservationDeviceOptionItem>]>
Returns ordered list items when the effective form was a sequence.