pub struct ProjectCredentialSpec { /* private fields */ }Expand description
Effective service credential-spec members with independent provenance.
Implementations
Sourceimpl ProjectCredentialSpec
impl ProjectCredentialSpec
Sourcepub const fn config(&self) -> Option<&ProjectValue<String>>
pub const fn config(&self) -> Option<&ProjectValue<String>>
Returns the effective config reference without resolving top-level configs.
Sourcepub const fn file(&self) -> Option<&ProjectValue<String>>
pub const fn file(&self) -> Option<&ProjectValue<String>>
Returns the effective file reference without accessing the filesystem.
Sourcepub const fn registry(&self) -> Option<&ProjectValue<String>>
pub const fn registry(&self) -> Option<&ProjectValue<String>>
Returns the effective registry reference without registry or account access.
Sourcepub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
pub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
Returns malformed, extension, and future-unknown members retained as evidence.