pub struct ProjectDeployReservationDevice { /* private fields */ }Expand description
One effective resource-reservation device with nested provenance.
Implementations
Sourceimpl ProjectDeployReservationDevice
impl ProjectDeployReservationDevice
Sourcepub const fn form(&self) -> ProjectDeployReservationDeviceForm
pub const fn form(&self) -> ProjectDeployReservationDeviceForm
Returns whether this effective item is a mapping or retained unmodeled sequence entry.
Sourcepub const fn capabilities(
&self,
) -> Option<&ProjectValue<Vec<ProjectValue<ProjectDeployReservationDeviceCapability>>>>
pub const fn capabilities( &self, ) -> Option<&ProjectValue<Vec<ProjectValue<ProjectDeployReservationDeviceCapability>>>>
Returns the required effective capabilities collection when its form was valid.
Sourcepub const fn driver(&self) -> Option<&ProjectValue<String>>
pub const fn driver(&self) -> Option<&ProjectValue<String>>
Returns the optional effective raw device driver and its provenance.
Sourcepub const fn count(&self) -> Option<&ProjectValue<DeployReservationDeviceCount>>
pub const fn count(&self) -> Option<&ProjectValue<DeployReservationDeviceCount>>
Returns the optional raw effective device allocation count and its provenance.
Sourcepub const fn device_ids(
&self,
) -> Option<&ProjectValue<Vec<ProjectValue<ProjectDeployReservationDeviceId>>>>
pub const fn device_ids( &self, ) -> Option<&ProjectValue<Vec<ProjectValue<ProjectDeployReservationDeviceId>>>>
Returns optional effective ordered device allocation IDs, including an explicit empty list.
Sourcepub const fn options(
&self,
) -> Option<&ProjectValue<ProjectDeployReservationDeviceOptions>>
pub const fn options( &self, ) -> Option<&ProjectValue<ProjectDeployReservationDeviceOptions>>
Returns optional effective schema-shaped device options with full provenance.
Sourcepub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
pub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
Returns extensions, unknown fields, and malformed members retained as evidence.