pub struct ProjectDeployResourceLimits { /* private fields */ }Expand description
Effective deploy resource limits with nested provenance.
Implementations
Sourceimpl ProjectDeployResourceLimits
impl ProjectDeployResourceLimits
Sourcepub const fn cpus(&self) -> Option<&ProjectValue<DeployResourceCpus>>
pub const fn cpus(&self) -> Option<&ProjectValue<DeployResourceCpus>>
Returns the effective deploy resource CPU scalar spelling and category.
Sourcepub const fn memory(&self) -> Option<&ProjectValue<DeployResourceMemory>>
pub const fn memory(&self) -> Option<&ProjectValue<DeployResourceMemory>>
Returns the effective deploy resource memory value and its provenance.
Sourcepub const fn pids(&self) -> Option<&ProjectValue<DeployResourcePids>>
pub const fn pids(&self) -> Option<&ProjectValue<DeployResourcePids>>
Returns the effective deploy resource PID scalar spelling and category.
Sourcepub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
pub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
Returns extensions, unknown fields, and malformed children retained as evidence.