pub struct ProjectDeployResourceReservations { /* private fields */ }Expand description
Effective deploy resource reservations with nested provenance.
Implementations
Sourceimpl ProjectDeployResourceReservations
impl ProjectDeployResourceReservations
Sourcepub const fn cpus(&self) -> Option<&ProjectValue<DeployResourceCpus>>
pub const fn cpus(&self) -> Option<&ProjectValue<DeployResourceCpus>>
Returns the effective deploy resource reservation CPU scalar spelling and category.
Sourcepub const fn memory(&self) -> Option<&ProjectValue<DeployResourceMemory>>
pub const fn memory(&self) -> Option<&ProjectValue<DeployResourceMemory>>
Returns the effective deploy resource reservation memory value and its provenance.
Sourcepub const fn generic_resources(
&self,
) -> Option<&ProjectValue<Vec<ProjectValue<ProjectDeployGenericResource>>>>
pub const fn generic_resources( &self, ) -> Option<&ProjectValue<Vec<ProjectValue<ProjectDeployGenericResource>>>>
Returns effective ordered generic-resource reservations, including an explicit empty list.
Sourcepub const fn devices(
&self,
) -> Option<&ProjectValue<Vec<ProjectValue<ProjectDeployReservationDevice>>>>
pub const fn devices( &self, ) -> Option<&ProjectValue<Vec<ProjectValue<ProjectDeployReservationDevice>>>>
Returns effective reservation devices, including an explicit empty list.
Sourcepub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
pub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
Returns extensions, unknown fields, and malformed children retained as evidence.