pub struct ProjectDeployResources { /* private fields */ }Expand description
Effective deploy resources with nested provenance.
Implementations
Sourceimpl ProjectDeployResources
impl ProjectDeployResources
Sourcepub const fn limits(&self) -> Option<&ProjectValue<ProjectDeployResourceLimits>>
pub const fn limits(&self) -> Option<&ProjectValue<ProjectDeployResourceLimits>>
Returns effective deploy resource limits without defaults or runtime interpretation.
Sourcepub const fn reservations(
&self,
) -> Option<&ProjectValue<ProjectDeployResourceReservations>>
pub const fn reservations( &self, ) -> Option<&ProjectValue<ProjectDeployResourceReservations>>
Returns effective resource reservations without scheduling interpretation.
Sourcepub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
pub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
Returns extensions, unknown fields, and malformed children retained as evidence.