pub struct ProjectExposeItem { /* private fields */ }Expand description
One effective service expose scalar with authored spelling and YAML kind retained.
Implementations
Sourceimpl ProjectExposeItem
impl ProjectExposeItem
Returns the exact scalar spelling before optional interpolation.
Sourcepub fn value(&self) -> &str
pub fn value(&self) -> &str
Returns the exact effective scalar spelling after optional interpolation.
Sourcepub const fn scalar_kind(&self) -> ExposeScalarKind
pub const fn scalar_kind(&self) -> ExposeScalarKind
Returns whether the YAML scalar was authored as a string or number.
Sourcepub const fn kind(&self) -> &ExposeItemKind
pub const fn kind(&self) -> &ExposeItemKind
Returns the conservative classification of the effective spelling.