pub struct ProjectKey { /* private fields */ }Expand description
A merged mapping key and every location at which that key was authored.
Implementations
Sourceimpl ProjectKey
impl ProjectKey
Sourcepub fn sources(&self) -> &[SourceSpan]
pub fn sources(&self) -> &[SourceSpan]
Returns authored key locations in merge order.
Sourcepub fn effective_source(&self) -> Option<SourceSpan>
pub fn effective_source(&self) -> Option<SourceSpan>
Returns the effective key location.
Sourcepub const fn is_sensitive(&self) -> bool
pub const fn is_sensitive(&self) -> bool
Reports whether interpolation inserted sensitive content into this semantic key.