pub struct ProjectLogging { /* private fields */ }Expand description
Effective service logging configuration with nested merge provenance retained.
Implementations
Sourceimpl ProjectLogging
impl ProjectLogging
Sourcepub const fn driver(&self) -> Option<&ProjectValue<String>>
pub const fn driver(&self) -> Option<&ProjectValue<String>>
Returns the uninterpreted effective YAML string driver.
Sourcepub const fn options(&self) -> Option<&ProjectValue<ProjectLoggingOptions>>
pub const fn options(&self) -> Option<&ProjectValue<ProjectLoggingOptions>>
Returns the ordered options mapping, including an explicitly empty one.
Sourcepub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
pub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
Returns extensions, unknown fields, and malformed known siblings retained in the mapping.