pub struct ProjectLoggingOption { /* private fields */ }Expand description
One ordered effective logging option with complete key and value provenance.
Implementations
Sourceimpl ProjectLoggingOption
impl ProjectLoggingOption
Sourcepub const fn name(&self) -> &ProjectKey
pub const fn name(&self) -> &ProjectKey
Returns the non-empty option name and every authored key location.
Sourcepub const fn value(&self) -> &ProjectValue<ProjectLoggingOptionValue>
pub const fn value(&self) -> &ProjectValue<ProjectLoggingOptionValue>
Returns the exact string, number, or null option value with merge provenance.