pub struct ProjectProviderOption { /* private fields */ }Expand description
One effective provider option with complete key and value provenance.
Implementations
Sourceimpl ProjectProviderOption
impl ProjectProviderOption
Sourcepub const fn name(&self) -> &ProjectKey
pub const fn name(&self) -> &ProjectKey
Returns the non-empty option name and every authored key location.
Sourcepub const fn value(&self) -> &ProjectValue<ProjectProviderOptionValue>
pub const fn value(&self) -> &ProjectValue<ProjectProviderOptionValue>
Returns the scalar category or ordered sequence with complete merge provenance.