pub struct ProjectUlimitScalar { /* private fields */ }Expand description
One effective ulimit scalar with authored spelling and YAML scalar kind retained.
Implementations
Sourceimpl ProjectUlimitScalar
impl ProjectUlimitScalar
Returns the exact authored scalar spelling before optional interpolation.
Sourcepub const fn value(&self) -> &LimitValue
pub const fn value(&self) -> &LimitValue
Returns the classified effective spelling after optional interpolation.
Sourcepub const fn kind(&self) -> MergedScalarKind
pub const fn kind(&self) -> MergedScalarKind
Returns whether the authored YAML scalar was a string or number.