pub struct ProjectView { /* private fields */ }Expand description
The native consumer view of one merged and optionally profile-selected Compose project.
Implementations
Sourceimpl ProjectView
impl ProjectView
Sourcepub fn source_ids(&self) -> &[SourceId]
pub fn source_ids(&self) -> &[SourceId]
Returns source documents in merge order.
Sourcepub fn base_directory(&self) -> &Path
pub fn base_directory(&self) -> &Path
Returns the project directory inherited from the first loaded document.
Sourcepub const fn provenance(&self) -> &MergeProvenance
pub const fn provenance(&self) -> &MergeProvenance
Returns provenance for the complete merged root.
Sourcepub const fn name(&self) -> Option<&ProjectValue<String>>
pub const fn name(&self) -> Option<&ProjectValue<String>>
Returns the effective explicit project name.
Sourcepub fn services(&self) -> &[ProjectService]
pub fn services(&self) -> &[ProjectService]
Returns profile-active services in merged order.
Sourcepub fn service(&self, name: &str) -> Option<&ProjectService>
pub fn service(&self, name: &str) -> Option<&ProjectService>
Finds one profile-active service.
Sourcepub fn networks(&self) -> &[ProjectResource<NetworkDefinition>]
pub fn networks(&self) -> &[ProjectResource<NetworkDefinition>]
Returns effective top-level network definitions.
Sourcepub fn volumes(&self) -> &[ProjectResource<VolumeDefinition>]
pub fn volumes(&self) -> &[ProjectResource<VolumeDefinition>]
Returns effective top-level volume definitions.
Sourcepub fn configs(&self) -> &[ProjectResource<ConfigDefinition>]
pub fn configs(&self) -> &[ProjectResource<ConfigDefinition>]
Returns effective top-level config definitions.
Sourcepub fn secrets(&self) -> &[ProjectResource<SecretDefinition>]
pub fn secrets(&self) -> &[ProjectResource<SecretDefinition>]
Returns effective top-level secret definitions.
Sourcepub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
pub fn unmodeled_fields(&self) -> &[ProjectFieldReference]
Returns root fields retained outside this initial native project-view boundary.