pub struct ProjectViewResult { /* private fields */ }Expand description
Recoverable result of building a typed merged project view.
Implementations
Sourceimpl ProjectViewResult
impl ProjectViewResult
Sourcepub const fn view(&self) -> Option<&ProjectView>
pub const fn view(&self) -> Option<&ProjectView>
Returns the typed view when the profile selection belongs to the project.
Sourcepub fn diagnostics(&self) -> &[Diagnostic]
pub fn diagnostics(&self) -> &[Diagnostic]
Returns project-view diagnostics in traversal order.
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Reports whether a view exists and contains no error diagnostics.
Sourcepub fn into_parts(self) -> (Option<ProjectView>, Vec<Diagnostic>)
pub fn into_parts(self) -> (Option<ProjectView>, Vec<Diagnostic>)
Separates the view and diagnostics.