#[non_exhaustive]pub enum GeneratedSysctls {
Map(Vec<GeneratedSysctl>),
List(Vec<GeneratedString>),
}Expand description
The mapping or list form selected for generated service sysctls.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Map(Vec<GeneratedSysctl>)
Ordered unique-name mapping assignments, including an explicit empty mapping.
List(Vec<GeneratedString>)
Ordered unique exact strings, including an explicit empty list.