pub struct CanonicalFormatting { /* private fields */ }Expand description
Presentation-only options for deterministic merged-project rendering.
These options cannot interpolate, merge, select profiles, apply defaults, reorder mappings,
or change retained Compose short/long forms. Self::default is the fixed canonical-v1 format.
Implementations
Sourceimpl CanonicalFormatting
impl CanonicalFormatting
Sourcepub const fn indent_width(self) -> IndentWidth
pub const fn indent_width(self) -> IndentWidth
Returns the number of spaces used for each nested YAML level.
Sourcepub const fn line_ending(self) -> LineEnding
pub const fn line_ending(self) -> LineEnding
Returns the selected line-ending convention.
Sourcepub const fn document_marker(self) -> bool
pub const fn document_marker(self) -> bool
Reports whether output starts with a YAML document marker.
Sourcepub const fn final_newline(self) -> bool
pub const fn final_newline(self) -> bool
Reports whether non-empty output ends with the selected line ending.
Sourcepub const fn with_indent_width(self, indent_width: IndentWidth) -> Self
pub const fn with_indent_width(self, indent_width: IndentWidth) -> Self
Returns options with a different validated indentation width.
Sourcepub const fn with_line_ending(self, line_ending: LineEnding) -> Self
pub const fn with_line_ending(self, line_ending: LineEnding) -> Self
Returns options with a different line-ending convention.
Sourcepub const fn with_document_marker(self, document_marker: bool) -> Self
pub const fn with_document_marker(self, document_marker: bool) -> Self
Returns options with YAML document-marker emission enabled or disabled.
Sourcepub const fn with_final_newline(self, final_newline: bool) -> Self
pub const fn with_final_newline(self, final_newline: bool) -> Self
Returns options with a final line ending enabled or disabled.