pub struct CanonicalRender { /* private fields */ }Expand description
The result of deterministic canonical rendering.
The output can contain interpolated secrets and is therefore available only through explicit
accessors. Its Debug representation redacts the complete output when any rendered value is
sensitive.
Implementations
Sourceimpl CanonicalRender
impl CanonicalRender
Sourcepub fn into_output(self) -> String
pub fn into_output(self) -> String
Consumes the result and returns the rendered document.
Sourcepub fn diagnostics(&self) -> &[Diagnostic]
pub fn diagnostics(&self) -> &[Diagnostic]
Returns canonical-rendering diagnostics.
Sourcepub const fn is_sensitive(&self) -> bool
pub const fn is_sensitive(&self) -> bool
Reports whether any rendered value contains sensitive interpolation output.