pub struct GeneratedLabel { /* private fields */ }Expand description
One generated service metadata label.
Implementations
Sourceimpl GeneratedLabel
impl GeneratedLabel
Sourcepub fn new(
name: impl Into<String>,
value: GeneratedString,
) -> Result<Self, GenerationError>
pub fn new( name: impl Into<String>, value: GeneratedString, ) -> Result<Self, GenerationError>
Creates a label with an explicit string value, including an empty value.
Errors
Rejects an empty or NUL-bearing label name. Values are already validated by
GeneratedString.
Sourcepub const fn value(&self) -> &GeneratedString
pub const fn value(&self) -> &GeneratedString
Returns the label value through its explicit sensitivity boundary.