pub struct GeneratedString { /* private fields */ }Expand description
A plain or sensitive string used by generated Compose fields.
Implementations
Sourceimpl GeneratedString
impl GeneratedString
Sourcepub fn plain(value: impl Into<String>) -> Result<Self, GenerationError>
pub fn plain(value: impl Into<String>) -> Result<Self, GenerationError>
Creates a non-sensitive generated string.
Errors
Returns GenerationError::ContainsNul when the value contains a NUL byte.
Sourcepub fn sensitive(value: impl Into<String>) -> Result<Self, GenerationError>
pub fn sensitive(value: impl Into<String>) -> Result<Self, GenerationError>
Creates a sensitive generated string whose debug representation is redacted.
Errors
Returns GenerationError::ContainsNul when the value contains a NUL byte.
Sourcepub const fn is_sensitive(&self) -> bool
pub const fn is_sensitive(&self) -> bool
Reports whether debug output must redact this value.