pub struct Reference { /* private fields */ }Expand description
One source-aware Compose cross-reference.
Implementations
Sourceimpl Reference
impl Reference
Sourcepub fn source_service(&self) -> &str
pub fn source_service(&self) -> &str
Returns the service containing the reference.
Sourcepub const fn source(&self) -> SourceSpan
pub const fn source(&self) -> SourceSpan
Returns the reference source span.
Sourcepub const fn kind(&self) -> ReferenceKind
pub const fn kind(&self) -> ReferenceKind
Returns the reference kind.
Sourcepub const fn status(&self) -> ReferenceStatus
pub const fn status(&self) -> ReferenceStatus
Returns whether the target is available.
Sourcepub const fn is_sensitive(&self) -> bool
pub const fn is_sensitive(&self) -> bool
Reports whether interpolation inserted sensitive content into the target name.
Sourcepub const fn is_required(&self) -> bool
pub const fn is_required(&self) -> bool
Reports whether an unavailable dependency is an error rather than a warning.
Non-dependency reference kinds are always required.