#[non_exhaustive]pub enum DeployReservationDeviceOptions {
Map {
span: SourceSpan,
entries: Vec<KeyValueEntry>,
unmodeled_entries: Vec<FieldReference>,
},
List {
span: SourceSpan,
items: Vec<DeployReservationDeviceOptionItem>,
},
}Expand description
Schema-shaped resource-reservation device options retaining map or list syntax.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Map
Ordered mapping entries plus malformed or duplicate fields retained as evidence.
Fields

span: SourceSpanComplete mapping span.

entries: Vec<KeyValueEntry>Valid non-empty strict-string keyed scalar entries.

unmodeled_entries: Vec<FieldReference>Malformed or duplicate mapping fields.
List
Ordered list entries, including malformed entries.
Fields

span: SourceSpanComplete sequence span.

items: Vec<DeployReservationDeviceOptionItem>Items in authored order.
Implementations
Sourceimpl DeployReservationDeviceOptions
impl DeployReservationDeviceOptions
Sourcepub const fn span(&self) -> SourceSpan
pub const fn span(&self) -> SourceSpan
Returns the complete authored collection span.
Sourcepub fn as_map(&self) -> Option<&[KeyValueEntry]>
pub fn as_map(&self) -> Option<&[KeyValueEntry]>
Returns valid map entries when the authored form was a mapping.
Sourcepub fn unmodeled_entries(&self) -> Option<&[FieldReference]>
pub fn unmodeled_entries(&self) -> Option<&[FieldReference]>
Returns malformed or duplicate map fields when the authored form was a mapping.
Sourcepub fn as_list(&self) -> Option<&[DeployReservationDeviceOptionItem]>
pub fn as_list(&self) -> Option<&[DeployReservationDeviceOptionItem]>
Returns ordered list entries when the authored form was a sequence.