pub struct ReplacementScalar { /* private fields */ }Expand description
A typed scalar value to place at an existing YAML value-scalar span.
Implementations
Sourceimpl ReplacementScalar
impl ReplacementScalar
Sourcepub fn string(value: impl Into<String>) -> Self
pub fn string(value: impl Into<String>) -> Self
Creates a non-sensitive YAML string replacement.
Sourcepub fn sensitive_string(value: impl Into<String>) -> Self
pub fn sensitive_string(value: impl Into<String>) -> Self
Creates a sensitive YAML string replacement.
The value remains available only through the explicit edit operation. Debug output for
the replacement, containing edit, and successful result is redacted.
Sourcepub fn number(value: impl Into<String>) -> Self
pub fn number(value: impl Into<String>) -> Self
Creates a YAML number replacement whose spelling is validated when the edit is applied.
Sourcepub const fn is_sensitive(&self) -> bool
pub const fn is_sensitive(&self) -> bool
Reports whether the replacement contains sensitive caller-supplied content.